/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg;

import java.util.function.Function;
import org.apache.iceberg.io.CloseableIterable;

class StaticTableScan extends BaseMetadataTableScan {
  private final Function<StaticTableScan, DataTask> buildTask;

  StaticTableScan(
      Table table,
      Schema schema,
      MetadataTableType tableType,
      Function<StaticTableScan, DataTask> buildTask) {
    super(table, schema, tableType);
    this.buildTask = buildTask;
  }

  StaticTableScan(
      Table table,
      Schema schema,
      MetadataTableType tableType,
      Function<StaticTableScan, DataTask> buildTask,
      TableScanContext context) {
    super(table, schema, tableType, context);
    this.buildTask = buildTask;
  }

  @Override
  protected TableScan newRefinedScan(Table table, Schema schema, TableScanContext context) {
    return new StaticTableScan(table, schema, tableType(), buildTask, context);
  }

  @Override
  protected CloseableIterable<FileScanTask> doPlanFiles() {
    return CloseableIterable.withNoopClose(buildTask.apply(this));
  }
}
